@@ -18,11 +18,18 @@ def make_camel_case(string):
     for index, word in enumerate(string.split(" ")):
         uppercase_char_count = 0
 
+        if word.startswith("https://") or word.startswith("www."):
+            continue
+
         for char in word:
             if char.isupper():
                 uppercase_char_count += 1
 
-        uppercase_char_percantage = uppercase_char_count / len(word) * 100
+        if len(word) == 0:
+            uppercase_char_percantage = 100
+        else:
+            uppercase_char_percantage = uppercase_char_count / len(word) * 100
+
         if uppercase_char_percantage < 50:
             string_split[index] = f"{word[0].upper()}{word[1:]}"
 
@@ -85,6 +92,9 @@ class Logger:
     def print_formatted(self, string, prefix, colour):
         print(formatString(string, prefix, colour, self.should_camel_case))
 
+    def print(self, string, prefix=""):
+        self.print_formatted(f"|=|{string}|=|", prefix, Colours.white)
+
     def log(self, string, prefix=""):
         """Used for general logs. Prints to the console formatted with YELLOW colour.
 
